pub struct SharedKeys<E: Scalar, G: GroupElement<E>> {
pub alpha: GenericArray<u8, G::AlphaLen>,
pub secrets: Vec<SharedSecret>,
_d: PhantomData<(E, G)>,
}Expand description
Structure containing shared keys for peers using the Sphinx algorithm.
Fields
alpha: GenericArray<u8, G::AlphaLen>secrets: Vec<SharedSecret>_d: PhantomData<(E, G)>Implementations
Sourcepub(crate) fn generate(
peer_group_elements: Vec<(G, &GenericArray<u8, G::AlphaLen>)>,
) -> Result<SharedKeys<E, G>>
pub(crate) fn generate( peer_group_elements: Vec<(G, &GenericArray<u8, G::AlphaLen>)>, ) -> Result<SharedKeys<E, G>>
Generates shared secrets given the group element of the peers and their Alpha value encodings.
The order of the peer group elements is preserved for resulting shared keys.
Sourcepub(crate) fn forward_transform(
alpha: &GenericArray<u8, G::AlphaLen>,
private_scalar: &E,
public_element_alpha: &GenericArray<u8, G::AlphaLen>,
) -> Result<(GenericArray<u8, G::AlphaLen>, SharedSecret)>
pub(crate) fn forward_transform( alpha: &GenericArray<u8, G::AlphaLen>, private_scalar: &E, public_element_alpha: &GenericArray<u8, G::AlphaLen>, ) -> Result<(GenericArray<u8, G::AlphaLen>, SharedSecret)>
Calculates the forward transformation given the local private key.
Efficiency note: the public_element_alpha is a precomputed group element Alpha encoding associated with the
private_scalar.