Alpha

Type Alias Alpha 

pub type Alpha<A> = Array<u8, A>;
Represents the Alpha value of a certain length in the Sphinx protocol The length of the alpha value is directly dependent on the group element.

Aliased Type

#[repr(transparent)]
pub struct Alpha<A>(pub <A as ArraySize>::ArrayType<u8>);

Tuple Fields

0: <A as ArraySize>::ArrayType<u8>